record_output

Function record_output 

pub fn record_output(line: String)
Append line to the history buffer, evicting the oldest entry when the buffer would exceed the configured capacity. Intended to be called only from the aprintln! macro.